==> JuiceScript_linux_2023.11.27_21.44.35.tar.gz: ext.c <==
#include <stdio.h>
#include <stdint.h>
#include <assert.h>
#include <stdlib.h>
#include <string.h>
#ifndef  LIB_MODE
#include <ncurses.h>
#define el_printf(...)              do{printw(__VA_ARGS__);fprintf(log_fp,__VA_ARGS__);fflush(log_fp);}while(0)
#else
#define el_printf(...)              do{printf(__VA_ARGS__);fprintf(log_fp,__VA_ARGS__);fflush(log_fp);}while(0)
// #define el_printf(...)              do{}while(0)
#endif
#include "elang.h"

static FILE *log_fp;

int elang_ext_print(void** vm){
    elang_ext_data_type_t   type;
    unsigned char*          data;
    float                   fnum;
    el_uint32_t             len;
    int     ret;
    // el_printf("elang_ext_print\n");
    ret = elang_ext_pop_arg(&vm,&type,&data,&fnum,&len);
    // el_printf("     ret: %d\n",ret);
    // el_printf("     type: %d\n",type);
    // el_printf("     data: %p\n",data);
    // el_printf("     fnum: %f\n",fnum);
    // el_printf("     len: %d\n",len);
    switch(type){
        case ELANG_EXT_DATA_STR:
            // el_printf("     ELANG_EXT_DATA_STR\n");
            if(len > 0){
                el_printf("%s\n",data);
            }
        break;
        case ELANG_EXT_DATA_NIL:
            // el_printf("     ELANG_EXT_DATA_NIL\n");
            el_printf("nil\n");
        break;
        case ELANG_EXT_DATA_FLOAT:
            el_printf("%f\n",fnum);
        break;
        case ELANG_EXT_DATA_LIST:
            el_printf("list(%d)\n",len);
            // el_printf("     ELANG_EXT_DATA_LIST\n");
        break;
    }
    // ret = elang_ext_pop_arg(&vm,&type,&data,&fnum,&len);
    // el_printf("     ret: %d\n",ret);
    // el_printf("     type: %d\n",type);
    // el_printf("     data: %p\n",data);
    // el_printf("     fnum: %f\n",fnum);
    // el_printf("     len: %d\n",len);
    // switch(type){
    //     case ELANG_EXT_DATA_STR:
    //         el_printf("     ELANG_EXT_DATA_STR\n");
    //         if(len > 0){
    //             el_printf("         %s\n",data);
    //         }
    //     break;
    //     case ELANG_EXT_DATA_NIL:
    //         el_printf("     ELANG_EXT_DATA_NIL\n");
    //     break;
    //     case ELANG_EXT_DATA_FLOAT:
    //         el_printf("     ELANG_EXT_DATA_FLOAT\n");
    //     break;
    //     case ELANG_EXT_DATA_LIST:
    //         el_printf("     ELANG_EXT_DATA_LIST\n");
    //     break;
    // }
}
int elang_ext_boot_hook(void** vm){
    log_fp = fopen("ext_log.txt","w+");
    if(NULL == log_fp) {
        printf("open failed\n");
        return -1;
    }
    elang_ext_register_func(&vm,"print",elang_ext_print);

}

int elang_ext_exit_hook(void** vm){
    fclose(log_fp);
}

==> JuiceScript_linux_2023.11.29_22.32.10.tar.gz: ext.c <==
#include <stdio.h>
#include <stdint.h>
#include <assert.h>
#include <stdlib.h>
#include <string.h>
#ifndef  LIB_MODE
#include <ncurses.h>
#define el_printf(...)              do{printw(__VA_ARGS__);fprintf(log_fp,__VA_ARGS__);fflush(log_fp);}while(0)
#else
#define el_printf(...)              do{printf(__VA_ARGS__);fprintf(log_fp,__VA_ARGS__);fflush(log_fp);}while(0)
// #define el_printf(...)              do{}while(0)
#endif
#include "elang.h"
static FILE *log_fp;
int elang_ext_print(void** vm){
    elang_ext_data_type_t   type;
    unsigned char*          data;
    float                   fnum;
    el_uint32_t             len;
    int     ret;
    // el_printf("elang_ext_print\n");
    ret = elang_ext_pop_arg(&vm,&type,&data,&fnum,&len);
    // el_printf("     ret: %d\n type: %d data: %p fnum: %f len: %d\n",ret,type,data,fnum,len);
    switch(type){
        case ELANG_EXT_DATA_STR:
            if(len > 0){
                el_printf("%s\n",data);
            }
        break;
        case ELANG_EXT_DATA_NIL:
            el_printf("nil\n");
        break;
        case ELANG_EXT_DATA_FLOAT:
            el_printf("%f\n",fnum);
        break;
        case ELANG_EXT_DATA_LIST:
            el_printf("list(%d)\n",len);
        break;
    }
}
int elang_ext_boot_hook(void** vm){
    log_fp = fopen("ext_log.txt","w+");
    if(NULL == log_fp) {
        printf("open failed\n");
        return -1;
    }
    elang_ext_register_func(&vm,"print",elang_ext_print);
}

int elang_ext_exit_hook(void** vm){
    fclose(log_fp);
}
